@@ -9,13 +9,15 @@ import shutil
 import socket
 import tempfile
 import time
-import urllib
+
 from concurrent.futures import Future, ProcessPoolExecutor
 from datetime import datetime
 from itertools import zip_longest
 from multiprocessing import cpu_count
+from os import PathLike
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple
+from typing import Dict, List, Optional, Tuple, Union
+from urllib.parse import quote_plus
 
 from hoppr_cyclonedx_models.cyclonedx_1_4 import Component  # type: ignore
 from packageurl import PackageURL  # type: ignore
@@ -226,26 +228,35 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
         """
         return self.logger
 
-    def _collect_file(self, file_name, target_dir) -> None:
+    def _collect_file(
+        self,
+        file_name: Union[str, PathLike[str]],
+        target_dir: Union[str, PathLike[str]],
+    ) -> None:
         self.get_logger().info(f"Collecting metadata file {file_name}")
-        abs_path = os.path.abspath(file_name)
+        abs_path = Path(file_name).absolute()
 
-        target = os.path.join(target_dir, urllib.parse.quote_plus(abs_path))
-        shutil.copyfile(file_name, target)
+        target = Path(target_dir, quote_plus(f"{abs_path}"))
+        shutil.copyfile(file_name, f"{target}")
 
-    def _collect_url(self, url, target_dir) -> None:
+    def _collect_url(
+        self, url: Union[str, PathLike[str]], target_dir: Union[str, PathLike[str]]
+    ) -> None:
         self.get_logger().info(f"Collecting metadata from url {url}")
-        target = os.path.join(target_dir, urllib.parse.quote_plus(url))
-        download_file(url, target, None)
 
-    def _collect_manifest_metadata(self, manifest: Manifest, target_dir) -> None:
+        target = Path(target_dir, quote_plus(f"{url}"))
+        download_file(url, f"{target}", None)
+
+    def _collect_manifest_metadata(
+        self, manifest: Manifest, target_dir: Union[str, PathLike[str]]
+    ) -> None:
         for (child_ref, child) in zip_longest(
             manifest.manifest_file_content.includes, manifest.children
         ):
             if child_ref.local is not None:
                 self._collect_file(child_ref.local, target_dir)
             else:
-                self._collect_url(child_ref.url, target_dir)
+                self._collect_url(f"{child_ref.url}", Path(target_dir))
 
             self._collect_manifest_metadata(child, target_dir)
 
@@ -253,22 +264,26 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
             if bom_ref.local is not None:
                 self._collect_file(bom_ref.local, target_dir)
             else:
-                self._collect_url(bom_ref.url, target_dir)
+                self._collect_url(f"{bom_ref.url}", target_dir)
 
     def _collect_metadata(self):
         echo("Collecting Hoppr Metadata")
-        target_dir = f"{self.context.collect_root_dir}/generic/_metadata_/"
-        os.makedirs(target_dir, exist_ok=True)
+        target_dir = Path(self.context.collect_root_dir, "generic", "_metadata_")
+        target_dir.mkdir(exist_ok=True, parents=True)
 
         if "nux" in platform.system():
             user = pwd.getpwuid(os.getuid())[0]  # pylint: disable=no-member
         else:
             user = os.getlogin()
 
-        with open(target_dir + "_run_data_", "w", encoding="utf-8") as rundata:
-            rundata.write(f"Collection Start: {str(datetime.now())}\n")
-            rundata.write(f"User:             {user}\n")
-            rundata.write(f"Host FQDN:        {socket.getfqdn()}\n")
+        with open(target_dir.joinpath("_run_data_"), "w", encoding="utf-8") as rundata:
+            rundata.writelines(
+                [
+                    f"Collection Start: {str(datetime.now())}\n",
+                    f"User:             {user}\n",
+                    f"Host FQDN:        {socket.getfqdn()}\n",
+                ]
+            )
 
         for file_name in self.metadata_files:
             self._collect_file(file_name, target_dir)
@@ -277,10 +292,10 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
 
     def _collect_bom(self) -> None:
         target_dir = Path(self.context.collect_root_dir, "generic", "_metadata_")
-        os.makedirs(target_dir, exist_ok=True)
+        target_dir.mkdir(parents=True, exist_ok=True)
 
         with open(
-            os.path.join(target_dir, "_consolidated_bom.json"), "w", encoding="utf-8"
+            target_dir.joinpath("_consolidated_bom.json"), "w", encoding="utf-8"
         ) as bom_data:
             bom_data.write(self.context.consolidated_sbom.json(by_alias=True, indent=2))
 
